@@ -86,7 +86,7 @@
 #define SONNETUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SONNETUI_NO_DEPRECATED
-#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef SONNETUI_NO_DEPRECATED_WARNINGS
 #  define SONNETUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SONNETUI_DEPRECATED_WARNINGS_SINCE SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define SONNETUI_DEPRECATED_VERSION_5(minor, text)      SONNETUI_DEPRECATED_VERSION_5_##minor(text)
 #define SONNETUI_DEPRECATED_VERSION(major, minor, text) SONNETUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define SONNETUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) SONNETUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) SONNETUI_DEPRECATED_VERSION(major, minor, text)
+#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) SONNETUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* SONNETUI_EXPORT_H */
